"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const unist_util_visit_1 = require("unist-util-visit");
const node_fetch_1 = __importDefault(require("node-fetch"));
function extractLines(content, fromLine, hasDash, toLine, preserveTrailingNewline = false) {
    const lines = content.split(/\r\n|\n/);
    const start = fromLine || 1;
    let end;
    if (!hasDash) {
        end = start;
    }
    else if (toLine) {
        end = toLine;
    }
    else if (lines[lines.length - 1] === "" && !preserveTrailingNewline) {
        end = lines.length - 1;
    }
    else {
        end = lines.length;
    }
    return lines.slice(start - 1, end).join("\n");
}
const plugin = (options = {}) => {
    const transformer = async (tree, file) => {
        const codes = [];
        (0, unist_util_visit_1.visit)(tree, "code", (node) => {
            codes.push(node);
        });
        for (const node of codes) {
            const codeMeta = (node.meta || "")
                .split(" ")
                .find((meta) => meta.startsWith("raw_url="));
            if (!codeMeta) {
                continue;
            }
            const res = /^raw_url=(?<rawUrl>.+?)(?:(?:#(?:L(?<from>\d+)(?<dash>-)?)?)(?:L(?<to>\d+))?)?$/.exec(codeMeta);
            if (!res || !res.groups || !res.groups.rawUrl) {
                throw new Error(`Unable to parse raw url path ${codeMeta}`);
            }
            const rawUrl = res.groups.rawUrl;
            const fromLine = res.groups.from
                ? Number.parseInt(res.groups.from, 10)
                : undefined;
            const hasDash = !!res.groups.dash || fromLine === undefined;
            const toLine = res.groups.to
                ? Number.parseInt(res.groups.to, 10)
                : undefined;
            const response = await (0, node_fetch_1.default)(rawUrl);
            const fileContent = await response.text();
            node.value = extractLines(fileContent, fromLine, hasDash, toLine, options.preserveTrailingNewline);
            // FIX: warn unable to find prism language
            node.meta = undefined;
        }
    };
    return transformer;
};
exports.default = plugin;
//# sourceMappingURL=index.js.map